function woa01_surf( time )
%
% Script de creation d'un fichier NetCDF pour les donnees levitus
% annuelle WOA01 (WORLD OCEAN ATLAS 2001).
% Variables: temperature, salinite, oxygene ainsi que les ecarts types
% de ces parametres.
% Les noms des variables reprennent les codes ROSCOP prefixes de WOA_
%        temperature de surface -> WOA_SSTP
%        salinite de surface    -> WOA_SSPS
%
% Utilise la fonction de lecture des fichiers ASCII rdwoaan.m
% developpee par D Dagorne (IRD, nov 2004).
%
% Les fichiers de donnees sont a recuperer sous :
% - ftp://ftp.nodc.noaa.gov/pub/WOA01/DATA/temperature/grid
% - ftp://ftp.nodc.noaa.gov/pub/WOA01/DATA/salinity/grid
% - ftp://ftp.nodc.noaa.gov/pub/WOA01/DATA/oxygen/grid
%
% Description des fichiers:
% 
% The first value in a one-degree square file corresponds to the grid box centered 
% at latitude 89.5°S and longitude 0.5°E (grid box 1,1). 
% The first 360 values are incremented eastward in longitude, constant in latitude. 
% The 361st value is for the grid square centered at latitude 88.5°S and 
% longitude 0.5°E (grid box 2,1). 
% 
% Lire les fichiers sous ftp://ftp.nodc.noaa.gov/pub/WOA01/DOC:
% pour une description plus detaillee.
%
% Extraits:
% The following file types are contained within the annual, seasonal,
% and monthly directories:
%
% A. Analyzed fields (an) - One-degree all-data objectively analyzed
% mean.
% B. Difference fields (ma) - One-degree seasonal and monthly analyzed
% mean minus annual analyzed fields
% C. Grid point fields (gp) - One-degree number of grid points which
% contain data within the radius of influence for each grid box
% D. Number of observations (dd) - One-degree and five-degree
% geographic distribution of data used in analysis
% E. Standard deviation (sd) - One-degree and five-degree standard
% deviation from the mean 8
% F. Standard error of the mean (se) - One-degree and five-degree
% standard error of the mean
% G. Means (mn) - One-degree and five-degree unanalyzed means for all
% data used in analysis
% H. Interpolation error fields (oa) - One-degree analyzed field
% subtracted from one-degree unanalyzed (raw) means

% $Id: woa01an.m 272 2007-04-20 09:24:20Z jgrelet $

% creation du fichier netcdf
disp(['Creation fichier netcdf: woa01_' time '_surf.nc']);
nc = netcdf(['woa01_' time '_surf.nc'], 'clobber');

% Definitions:
% Attributs globaux
nc.description    = ['WOA01 CLIMATOLOGY Surface Levitus ' time];
nc.author         = 'J Grelet IRD US191 Brest';
nc.date           = datestr(now, 'dd mmm yyyy');

% Dimensions
switch time
  case 'annual'
    nc('WOA_TIME') = 1;      % time
    WOA_TIME       = [1];
    imin = 1; imax = 1; offset = 0;
  case 'seasonal'
    nc('WOA_TIME') = 4;      % time
    WOA_TIME       = [1:4];
    imin = 13; imax = 16;; offset = 12;
  case 'monthly'
    nc('WOA_TIME') = 12;      % time
    WOA_TIME        = [1:12];
    imin = 1; imax = 12;; offset = 0;
end
%nc('WOA_DEPH')     = 1;      % depth (surface and 10m)
nc('WOA_DEPH')     = 2;      % depth (surface and 10m)
nc('WOA_LATX')     = 180;    % latitude
nc('WOA_LONX')     = 360;    % longitude



% Variables
nc{'WOA_TIME'}      = ncfloat('WOA_TIME');
nc{'WOA_DEPH'}      = ncfloat('WOA_DEPH');
nc{'WOA_LATX'}      = ncfloat('WOA_LATX');
nc{'WOA_LONX'}      = ncfloat('WOA_LONX');
nc{'WOA_MEAN_SSTP'} = ncfloat({'WOA_TIME','WOA_DEPH','WOA_LATX','WOA_LONX'});
nc{'WOA_MEAN_SSPS'} = ncfloat({'WOA_TIME','WOA_DEPH','WOA_LATX','WOA_LONX'});
nc{'WOA_MEAN_DOX1'} = ncfloat({'WOA_TIME','WOA_DEPH','WOA_LATX','WOA_LONX'});
nc{'WOA_STD_SSTP'}  = ncfloat({'WOA_TIME','WOA_DEPH','WOA_LATX','WOA_LONX'});
nc{'WOA_STD_SSPS'}  = ncfloat({'WOA_TIME','WOA_DEPH','WOA_LATX','WOA_LONX'});
nc{'WOA_STD_DOX1'}  = ncfloat({'WOA_TIME','WOA_DEPH','WOA_LATX','WOA_LONX'});
nc{'WOA_OBS_SSTP'}  = ncshort({'WOA_TIME','WOA_DEPH','WOA_LATX','WOA_LONX'});
nc{'WOA_OBS_SSPS'}  = ncshort({'WOA_TIME','WOA_DEPH','WOA_LATX','WOA_LONX'});
nc{'WOA_OBS_DOX1'}  = ncshort({'WOA_TIME','WOA_DEPH','WOA_LATX','WOA_LONX'});

% Attributs.
nc{'WOA_LATX'}.long_name       = 'Latitude';
nc{'WOA_LATX'}.units           = 'degree_north';
nc{'WOA_LATX'}.FillValue_      = -99.9999;
nc{'WOA_LONX'}.long_name       = 'Longitude';
nc{'WOA_LONX'}.units           = 'degree_east';
nc{'WOA_LONX'}.FillValue_      = -99.9999;
nc{'WOA_DEPH'}.long_name       = 'Depth';
nc{'WOA_DEPH'}.units           = 'meters';
nc{'WOA_DEPH'}.FillValue_      = -99.9999;
nc{'WOA_MEAN_SSTP'}.long_name  = 'Sea Surface Temperature mean';
nc{'WOA_MEAN_SSTP'}.units      = 'degre Celcius';
nc{'WOA_MEAN_SSTP'}.FillValue_ = -99.9999;
nc{'WOA_MEAN_SSPS'}.long_name  = 'Sea Surface Salinity mean';
nc{'WOA_MEAN_SSPS'}.units      = 'PSU';
nc{'WOA_MEAN_SSPS'}.FillValue_ = -99.9999;
nc{'WOA_MEAN_DOX1'}.long_name  = 'Sea Surface Dissolved oxygen mean';
nc{'WOA_MEAN_DOX1'}.units      = 'ml/l';
nc{'WOA_MEAN_DOX1'}.FillValue_ = -99.9999;
nc{'WOA_STD_SSTP'}.long_name   = 'Sea Surface Temperature standard deviation';
nc{'WOA_STD_SSTP'}.units       = 'degre Celcius';
nc{'WOA_STD_SSTP'}.FillValue_  = -99.9999;
nc{'WOA_STD_SSPS'}.long_name   = 'Sea Surface Salinity standard deviation';
nc{'WOA_STD_SSPS'}.units       = 'PSU';
nc{'WOA_STD_SSPS'}.FillValue_  = -99.9999;
nc{'WOA_STD_DOX1'}.long_name   = 'Sea Surface Dissolved oxygen standard deviation';
nc{'WOA_STD_DOX1'}.units       = 'ml/l';
nc{'WOA_STD_DOX1'}.FillValue_  = -99.9999;
nc{'WOA_OBS_SSTP'}.long_name   = 'Sea Surface Temperature number observation';
nc{'WOA_OBS_SSTP'}.units       = 'none';
nc{'WOA_OBS_SSTP'}.FillValue_  = -100;
nc{'WOA_OBS_SSPS'}.long_name   = 'Sea Surface Salinity number observation';
nc{'WOA_OBS_SSPS'}.units       = 'none';
nc{'WOA_OBS_SSPS'}.FillValue_  = -100;
nc{'WOA_OBS_DOX1'}.long_name   = 'Sea Surface Dissolved oxygen number observation';
nc{'WOA_OBS_DOX1'}.units       = 'none';
nc{'WOA_OBS_DOX1'}.FillValue_  = -100;

% Vecteurs des dimensions
WOA_DEPH = [0 10];
%WOA_DEPH = [0];
WOA_LATX = [-89.5:1:89.5];
WOA_LONX = [-179.5:1:179.5];


% Affectations des dimensions
nc{'WOA_TIME'}(:)  = WOA_TIME;
nc{'WOA_DEPH'}(:)  = WOA_DEPH;
nc{'WOA_LATX'}(:)  = WOA_LATX;
nc{'WOA_LONX'}(:)  = WOA_LONX;


for i=imin:imax
  if strcmp(time, 'annual')
    num = '00';
  else
    num = sprintf('%02d', i);
  end
  % Affectations des variables
  nc{'WOA_MEAN_SSTP'}(i-offset,:,:,:) = rdwoa([time filesep 't' num 'an1']);
  nc{'WOA_MEAN_SSPS'}(i-offset,:,:,:) = rdwoa([time filesep 's' num 'an1']);
  nc{'WOA_MEAN_DOX1'}(i-offset,:,:,:) = rdwoa([time filesep 'o' num 'an1']);
  nc{'WOA_STD_SSTP'}(i-offset,:,:,:)  = rdwoa([time filesep 't' num 'sd1']);
  nc{'WOA_STD_SSPS'}(i-offset,:,:,:)  = rdwoa([time filesep 's' num 'sd1']);
  nc{'WOA_STD_DOX1'}(i-offset,:,:,:)  = rdwoa([time filesep 'o' num 'sd1']);
  nc{'WOA_OBS_SSTP'}(i-offset,:,:,:)  = rdwoa([time filesep 't' num 'dd1']);
  nc{'WOA_OBS_SSPS'}(i-offset,:,:,:)  = rdwoa([time filesep 's' num 'dd1']);
  nc{'WOA_OBS_DOX1'}(i-offset,:,:,:)  = rdwoa([time filesep 'o' num 'dd1']);
end

% Fermeture du fichier
nc = close(nc);

clear all;

% ----------------------------------------------------------------
% lecture fichier climato WOA tous niveaux
% ----------------------------------------------------------------
  function [B] = rdwoa(fic)

    %
    % =====================================
    % WOA 01  CLIMATOLOGY   (LEVITUS ??)
    % reorganisation grille -180 / 180
    %
    % fichier ASCII
    % 10 valeurs par enregistrement
    %
    % 6480 val , 648 ligne par niveaux
    % domaine  90S- 90N /  /  0 - 360  , pas 1deg*1deg
    % 1 erlignes/colonnes : X-Y / bas-Gauche  ( -90, 0)
    % valeur manquante -99.9999   ( 8 char !!)
    %

    % fichier LEVITUS WOA
    disp(fic)
    %
    % load impossible car ligne  sans separateur pour valeur manquante
    %  ouverture
    fid = fopen(fic,'r');
    %
    %  init parametre grille
    % origine geographique bas - droite en colonnes , lignes 90S / equ
    nbcol=360;
    nblig=180;
    latpas=1;
    lonpas=1;
    %
    % modif  -180 / 180
    %londeb = 0.5;
    londeb=-179.5;
    latdeb=-89.5;
    %
    % fin geographique de la grille
    lonfin= (londeb + lonpas*nbcol) - 1;
    latfin =(latdeb + latpas*nblig) - 1;
    %
    % vecteur geoloc
    klon=[londeb:lonpas:lonfin];
    klat=[latdeb:latpas:latfin];

    % profondeur min 1, max 24 ou 33 niveaux
    nblev=length(WOA_DEPH);

    % formation SSS  LEVITUS
    % tableau  90 lignes * 180 colonnes
    %
    % 1 record de 10 valeurs F8.4 par enregistrement dfe 80 char
    % 180 groupes de 36 records de 10  valeurs
    %
    % boucke niveau
    for ip=1:nblev

      chtext=[' - niveau : ', num2str(ip)];
      disp(chtext);

      % lecture par niveaux
      for il=1:180
        for ik=1:36
          ic1=ik*10 - 9;
          ic2= ik*10;
          A(ic1:ic2,il) = fscanf(fid,'%e',10);
        end
        %
        % reorg -180 / 180
        % et transposition  ( ligne / colonne)
        %B(il,181:360,ip) = A(1:180,il);
        %B(il,1:180,ip) = A(181:360,il);
        B(ip,il,181:360) = A(1:180,il);
        B(ip,il,1:180) = A(181:360,il);
        % fin boucle surface
      end
      %
      % fin boucle niveau
    end

    % elimination valeur terre
    %B(find(B==-99.9999))=NaN;

  end

end
